==> mx-datetime_21.7.1.tar.xz: mx-datetime-21.7.1/translations/mx-datetime_tr.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="tr">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="596"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Tarih &amp; Saat</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Tarih &amp;&amp; Saat</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>S:dd:ss</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Donanım Saati</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Donanım Saati araçları</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Donanım Saatinden bilgi edin ve aşağıdaki kutuda göster.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Donanım Saatini Oku</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="303"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="306"/>
        <source>Drift Adjust</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Time transfer</source>
        <translation>Zaman aktarımı</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Sistem Saati&apos;ni Hemen Donanım Saati tarafından kaydedilen geçerli zamana uyacak şekilde ayarla.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="338"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Donanım Saatini Sistem Saatine</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Donanım Saati&apos;ni Hemen Sistem Saati tarafından kaydedilen geçerli zamana uyacak şekilde ayarla.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Sistem Saatini Donanım Saatine</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="364"/>
        <source>Update the drift</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="374"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Donanım Saati için Saat Dilimi</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="380"/>
        <source>Local time</source>
        <translation>Yerel zaman</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="383"/>
        <source>Local</source>
        <translation>Yerel</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="390"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Evrensel Koordineli Saat (veya Greenwich Meridyen Saati)</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="393"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="433"/>
        <source>Network Time</source>
        <translation>Ağ Saati</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="439"/>
        <source>Move the selected item down</source>
        <translation>Seçili öğeyi aşağı kaydır</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="450"/>
        <source>Move the selected item up</source>
        <translation>Seçili öğeyi yukarı kaydır</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="461"/>
        <source>Remove the current item from the list</source>
        <translation>Şu anki öğeyi listeden çıkar</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="472"/>
        <source>Add an item to the list</source>
        <translation>Listeye bir öğe ekle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="498"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Sistem saatini NTP sunucuları ile otomatik olarak güncelle:</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="505"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Sistem saatini NTP sunucuları ile hemen güncelleyin.</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="508"/>
        <source>Update Now</source>
        <translation>Şimdi Güncelle</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="520"/>
        <source>List of NTP servers to use.</source>
        <translation>Kullanılacak NTP sunucuları listesi</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="536"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="541"/>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="546"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Okunuyor...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="296"/>
        <location filename="../datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="350"/>
        <source>Updating...</source>
        <translation>Güncelleniyor...</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="360"/>
        <source>The system clock was updated successfully.</source>
        <translation>Sistem saati başarıyla güncellendi.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="362"/>
        <source>The system clock could not be updated.</source>
        <translation>Sistem saati güncellenemedi.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="364"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Listedeki NTP sunucularının hiçbiri şu anda etkin değil.</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="595"/>
        <source>About MX Date &amp; Time</source>
        <translation>MX Tarih &amp; Saat Hakkında</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="596"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="597"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>MX Linux &apos;ta tarih ve saati ayarlamak için grafik arayüzlü program</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="599"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="600"/>
        <location filename="../datetime.cpp" line="614"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="601"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="602"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="628"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="646"/>
        <source>MX Date &amp; Time Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-datetime_21.11.tar.xz: mx-datetime-21.11/translations/mx-datetime_tr.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="tr" version="2.1">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="datetime.ui" line="20"/>
        <location filename="datetime.cpp" line="596"/>
        <source>MX Date &amp; Time</source>
        <translation>MX Tarih &amp; Saat</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="26"/>
        <source>Close</source>
        <translation>Kapat</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="40"/>
        <source>Help</source>
        <translation>Yardım</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="73"/>
        <source>Apply</source>
        <translation>Uygula</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="100"/>
        <source>About...</source>
        <translation>Hakkında...</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation>Tarih &amp;&amp; Saat</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation>S:dd:ss</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="278"/>
        <location filename="datetime.cpp" line="296"/>
        <location filename="datetime.cpp" line="303"/>
        <source>Hardware Clock</source>
        <translation>Donanım Saati</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation>Donanım Saati araçları</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation>Donanım Saatinden bilgi edin ve aşağıdaki kutuda göster.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation>Donanım Saatini Oku</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="300"/>
        <source>Apply systematic drift corrections to the Hardware Clock.</source>
        <translation>Donanım Saatine sistematik sapma düzeltmeleri uygulayın.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="303"/>
        <source>Drift Adjust</source>
        <translation>Sapma Ayarı</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="323"/>
        <source>Time transfer</source>
        <translation>Zaman aktarımı</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="329"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation>Sistem Saati&apos;ni Hemen Donanım Saati tarafından kaydedilen geçerli zamana uyacak şekilde ayarla.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="332"/>
        <source>Hardware Clock to System Clock</source>
        <translation>Donanım Saatini Sistem Saatine</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="339"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation>Donanım Saati&apos;ni Hemen Sistem Saati tarafından kaydedilen geçerli zamana uyacak şekilde ayarla.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="342"/>
        <source>System Clock to Hardware Clock</source>
        <translation>Sistem Saatini Donanım Saatine</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="349"/>
        <source>Update the drift factor for the Hardware Clock when it is being set.</source>
        <translation>Donanım Saati ayarlanırken sapma etkenini güncelleyin.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="352"/>
        <source>Update the drift</source>
        <translation>Sapmayı güncelle</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="362"/>
        <source>Time zone for the Hardware Clock</source>
        <translation>Donanım Saati için Saat Dilimi</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="368"/>
        <source>Local time</source>
        <translation>Yerel zaman</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="371"/>
        <source>Local</source>
        <translation>Yerel</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="378"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation>Evrensel Koordineli Saat (veya Greenwich Meridyen Saati)</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="381"/>
        <source>UTC</source>
        <translation>UTC</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="421"/>
        <source>Network Time</source>
        <translation>Ağ Saati</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="427"/>
        <source>Move the selected item down</source>
        <translation>Seçili öğeyi aşağı kaydır</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="438"/>
        <source>Move the selected item up</source>
        <translation>Seçili öğeyi yukarı kaydır</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="449"/>
        <source>Remove the current item from the list</source>
        <translation>Şu anki öğeyi listeden çıkar</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="460"/>
        <source>Add an item to the list</source>
        <translation>Listeye bir öğe ekle</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="486"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation>Sistem saatini NTP sunucuları ile otomatik olarak güncelle:</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="493"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation>Sistem saatini NTP sunucuları ile hemen güncelleyin.</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="496"/>
        <source>Update Now</source>
        <translation>Şimdi Güncelle</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="505"/>
        <source>List of NTP servers to use.</source>
        <translation>Kullanılacak NTP sunucuları listesi</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="521"/>
        <source>Type</source>
        <translation>Tür</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="526"/>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <location filename="datetime.ui" line="531"/>
        <source>Options</source>
        <translation>Seçenekler</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation>Okunuyor...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="284"/>
        <source>Adjusting...</source>
        <translation>Ayarlanıyor...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="296"/>
        <location filename="datetime.cpp" line="303"/>
        <source>System Clock</source>
        <translation>Sistem Saati</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="309"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation>% 1 zamanı % 2&apos;ye aktarıldı.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="312"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation>%1 zamanı %2&apos;ye aktarılamadı.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="350"/>
        <source>Updating...</source>
        <translation>Güncelleniyor...</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="360"/>
        <source>The system clock was updated successfully.</source>
        <translation>Sistem saati başarıyla güncellendi.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="362"/>
        <source>The system clock could not be updated.</source>
        <translation>Sistem saati güncellenemedi.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="364"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation>Listedeki NTP sunucularının hiçbiri şu anda etkin değil.</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="595"/>
        <source>About MX Date &amp; Time</source>
        <translation>MX Tarih &amp; Saat Hakkında</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="596"/>
        <source>Version: </source>
        <translation>Sürüm</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="597"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation>MX Linux &apos;ta tarih ve saati ayarlamak için grafik arayüzlü program</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="599"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="600"/>
        <location filename="datetime.cpp" line="614"/>
        <source>License</source>
        <translation>Ruhsat</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="601"/>
        <source>Changelog</source>
        <translation>Değişim günlüğü</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="602"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="628"/>
        <source>&amp;Close</source>
        <translation>&amp;Kapat</translation>
    </message>
    <message>
        <location filename="datetime.cpp" line="646"/>
        <source>MX Date &amp; Time Help</source>
        <translation>MX Tarih ve Zaman Yardımı</translation>
    </message>
</context>
</TS>
